/*
   orxonox - the future of 3D-vertical-scrollers

   Copyright (C) 2004 orx

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   ### File Specific:
   main-programmer: Benjamin Grauer
   co-programmer: ...
*/

#define DEBUG_SPECIAL_MODULE DEBUG_MODULE_GUI

#include "glgui_table.h"

namespace OrxGui
{
  /**
   * @brief standard constructor
   */
  GLGuiTable::GLGuiTable ()
  {
    this->init();
  }


  /**
   * @brief standard deconstructor
   */
  GLGuiTable::~GLGuiTable()
  {}

  /**
   * @brief initializes the GUI-element
   */
  void GLGuiTable::init()
  {
    this->setClassID(CL_GLGUI_TABLE, "GLGuiTable");

    this->setFocusable(true);
    this->setClickable(true);

    this->resize();
  }


  void GLGuiTable::setRowCount(unsigned int rowCount)
  {
    this->_headers.resize(rowCount);
    for (unsigned int i = 0; i < rowCount; i++)
      this->_entries[i].resize(rowCount);

    if (!this->isVisible())
      this->hiding();
  }

  void GLGuiTable::setColumnCount(unsigned int columnCount)
  {
    this->_entries.resize(columnCount);
    if (!this->isVisible())
      this->hiding();
  }




  /**
   * removes the focus from this Widget.
   */
  void GLGuiTable::removedFocus()
  {
    GLGuiWidget::removedFocus();
  }



  /**
   * @brief Processes an Event.
   * @param event The event to be processed
   * @return true if the event was catched.
   */
  bool GLGuiTable::processEvent(const Event& event)
  {
    return false;
  }


  /**
   * @brief Resizes the Widget to the new Size-constraints.
   */
  void GLGuiTable::resize()
  {
    GLGuiWidget::resize();
  }

  void GLGuiTable::updateFrontColor()
  {
    for (unsigned int i = 0; i < this->rowCount(); ++i)
    {
      this->_headers[i].setColor(this->foregroundColor());
      for (unsigned int j = 0; j < this->columnCount(); ++j)
        this->_entries[i][j].setColor(this->foregroundColor());
    }
  }

  void GLGuiTable::hiding()
  {
    for (unsigned int i = 0; i < this->rowCount(); ++i)
    {
      this->_headers[i].setVisibility(false);
      for (unsigned int j = 0; j < this->columnCount(); ++j)
        this->_entries[i][j].setVisibility(false);
    }
  }

  void GLGuiTable::showing()
  {
    for (unsigned int i = 0; i < this->rowCount(); ++i)
    {
      this->_headers[i].setVisibility(true);
      for (unsigned int j = 0; j < this->columnCount(); ++j)
        this->_entries[i][j].setVisibility(true);
    }
  }

  /**
   * @brief ticks the Table
   * @param dt the time passed.
   */
  void GLGuiTable::tick(float dt)
  {
  }

  /**
   * @brief draws the GLGuiTable
   */
  void GLGuiTable::draw() const
  {
    this->beginDraw();
    GLGuiWidget::draw();

    //     this->frontMaterial().select();
    //     GLGuiWidget::drawRect(this->frontRect());

    this->endDraw();
  }
}
